# Copyright (c) 2022 BigRep GmbH

from typing import TYPE_CHECKING

from UM.Logger import Logger
from UM.Settings.ContainerRegistry import ContainerRegistry
from UM.Settings.Interfaces import ContainerInterface
from UM.Signal import Signal

from cura.Machines.ContainerNode import ContainerNode
from cura.Machines.MaterialNode import MaterialNode

import UM.FlameProfiler

if TYPE_CHECKING:
    from typing import Dict
    from cura.Machines.MachineNode import MachineNode
    from cura.Machines.VariantNode import VariantNode


class MachineVariantNode(ContainerNode):
    """
    This class represents a machine variant in the container tree.

    MachineNode     ->    [MachineVariantNode, MachineVariantNode]
    |             \
    VariantNode   VariantNode
    |
    MaterialNode
    |
    QualityNode
    """

    def __init__(self, container_id: str, build_plate: str, machine: "MachineNode") -> None:
        super().__init__(container_id)
        self.machine = machine
        self.build_plate = build_plate

        container_registry = ContainerRegistry.getInstance()
        self.machine_variant_name = container_registry.findContainersMetadata(id = container_id)[0]["name"]  # Store our own name so that we can filter more easily.
