// Copyright (c) 2022 UltiMaker
// Cura is released under the terms of the LGPLv3 or higher.
// Modified by BigRep GmbH 2024

import QtQuick 2.7
import QtQuick.Controls 2.4
import QtQuick.Layouts 2.7

import UM 1.5 as UM
import Cura 1.7 as Cura

/* This element is a workaround for MacOS, where it can crash in Qt6 when nested menus are closed.
Instead we'll use a pop-up which doesn't seem to have that problem. */

Cura.MenuItem
{
    id: machineTypeMenu
    height: UM.Theme.getSize("menu").height + UM.Theme.getSize("narrow_margin").height
    overrideShowArrow: true

    Component.onCompleted: {
        console.log("machineTypesModel.machineType")
        console.warn(machineTypesModel.machineType)
        console.warn(machineTypesModel.machines.length)
    }

    property var machineTypesModel
    text: machineTypesModel.machineType

    contentItem: MouseArea
    {
        hoverEnabled: true

        RowLayout
        {
            spacing: 0

            Item
            {
                // Spacer
                width: UM.Theme.getSize("default_margin").width
            }

            UM.Label
            {
                id: brandLabelText
                text: replaceText(machineTypeMenu.text)
                Layout.fillWidth: true
                Layout.fillHeight:true
                elide: Label.ElideRight
                wrapMode: Text.NoWrap
            }

            Item
            {
                Layout.fillWidth: true
            }

            Item
            {
                // Right side margin
                width: UM.Theme.getSize("default_margin").width
            }
        }

        onEntered: showTimer.restartTimer()
        onExited: hideTimer.restartTimer()
    }

    Timer
    {
        id: showTimer
        interval: 250
        function restartTimer()
        {
            restart();
            running = Qt.binding(function() { return machineTypeMenu.enabled && machineTypeMenu.contentItem.containsMouse; });
            hideTimer.running = false;
        }
        onTriggered: colorPopup.open()
    }
    Timer
    {
        id: hideTimer
        interval: 250
        function restartTimer() //Restart but re-evaluate the running property then.
        {
            restart();
            running = Qt.binding(function() { return machineTypeMenu.enabled && !machineTypeMenu.contentItem.containsMouse && !colorPopup.itemHovered > 0; });
            showTimer.running = false;
        }
        onTriggered: colorPopup.close()
    }

    MaterialBrandSubMenu
    {
        id: colorPopup

        // Nasty hack to ensure that we can keep track if the popup contains the mouse.
        // Since we also want a hover for the sub items (and these events are sent async)
        // We have to keep a count of itemHovered (instead of just a bool)
        property int itemHovered: 0

        Column
        {
            id: materialColorsList
            property var machines: machineTypesModel.machines
            width: machineTypeMenu.width
            height: childrenRect.height
            spacing: 0

            Repeater
            {
                model: parent.machines

                delegate: Rectangle
                {
                    height: UM.Theme.getSize("menu").height
                    width: parent.width

                    Component.onCompleted: {
                        console.log("model.name")
                        console.warn(model.name)
                    }

                    color: materialColorButton.containsMouse ? UM.Theme.getColor("background_2") : UM.Theme.getColor("main_background")

                    MouseArea
                    {
                        id: materialColorButton
                        anchors.fill: parent
                        hoverEnabled: true
                        onClicked:
                        {
                            Cura.MachineManager.setActiveMachine(model.id);
                            colorPopup.close();
                        }
                        onEntered:
                        {
                            colorPopup.itemHovered += 1;
                        }
                        onExited:
                        {
                            colorPopup.itemHovered -= 1;
                        }
                    }

                    Item
                    {
                        height: parent.height
                        width: parent.width
                        anchors.fill: parent

                        //Checkmark, if the material is selected.
                        UM.ColorImage
                        {
                            id: checkmark
                            // visible: model.id === materialMenu.activeMaterialId // TODO:
                            visible: true
                            height: UM.Theme.getSize("default_arrow").height
                            width: height
                            anchors.left: parent.left
                            anchors.leftMargin: UM.Theme.getSize("default_margin").width
                            anchors.verticalCenter: parent.verticalCenter
                            source: UM.Theme.getIcon("Check", "low")
                            color: UM.Theme.getColor("setting_control_text")
                        }

                        UM.Label
                        {
                            text: model.name
                            anchors.left: parent.left
                            anchors.leftMargin: UM.Theme.getSize("default_margin").width + UM.Theme.getSize("default_arrow").height
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.right: parent.right
                            anchors.rightMargin: UM.Theme.getSize("default_margin").width

                            elide: Label.ElideRight
                            wrapMode: Text.NoWrap
                        }
                    }
                }
            }
        }
    }
}
