// Copyright (c) 2023 BigRep GmbH
// Cura is released under the terms of the LGPLv3 or higher.
// closest reference is `RecommendedSupportSelector.qml`

import QtQuick 2.10
import QtQuick.Controls 2.3
import QtQuick.Layouts 1.3

import UM 1.5 as UM
import Cura 1.7 as Cura


RecommendedSettingSection
{
    id: printSurfaceRow
    
    //height: childrenRect.height
    title: catalog.i18nc("@label", "Print Surface")
    icon: UM.Theme.getIcon("Buildplate")
    tooltipText: catalog.i18nc("@label", "Allow selection of the desired build surface.")

    property int leftColumnWidth: Math.floor(width * 0.35)

    Cura.MachineVariantModel
    {
        id: machineVariantModel
    }

    Item
    {
        id: printSurfaceContainer
        height: parent.height

        anchors
        {
            left: parent.left
            leftMargin: leftColumnWidth + UM.Theme.getSize("medium_button_icon").width + UM.Theme.getSize("default_margin").width
            right: parent.right
            verticalCenter: sectionTitle.verticalCenter
        }

        Cura.ComboBox
        {
            id: printSurfaceCombobox
            anchors
            {
                left: parent.left
                right: parent.right
                //rightMargin: UM.Theme.getSize("default_margin").width
                verticalCenter: parent.verticalCenter
            }

            enabled: recommendedPrintSetup.settingsEnabled
            visible: true
            textRole: "id"  // this solves that the combobox isn't populated in the first time Cura is started

            model: machineVariantModel

            function getIndexByName(name)
            {
                var itemIndex = -1  // if name is not found, return -1
                for (var item_index in model.items)
                {
                    var item = model.getItem(item_index)
                    if (item.machine_variant_name == name)
                    {
                        itemIndex = item_index
                        break
                    }
                }
                return itemIndex
            }

            onActivated:
            {
                forceActiveFocus();
                Cura.MachineManager.setMachineVariantByName(model.getItem(index).machine_variant_name);
            }

            currentIndex: printSurfaceCombobox.getIndexByName(Cura.MachineManager.activeMachineVariantName)

            Connections
            {
                target: machineVariantModel
                function onModelChanged()
                {
                    supportExtruderCombobox.currentIndex = printSurfaceCombobox.getIndexByName(Cura.MachineManager.activeMachineVariantName)
                }
            }

            Binding
            {
                target: printSurfaceCombobox
                property: "currentIndex"
                value: printSurfaceCombobox.getIndexByName(Cura.MachineManager.activeMachineVariantName)
                // Sometimes when the value is already changed, the model is still being built.
                // The when clause ensures that the current index is not updated when this happens.
                when: printSurfaceCombobox.model.count > 0
            }

            // indicator: use default
            // background use default
            // contentItem use default
            // popup use default
            // delegate use default, modified by bigrep
        }
    }
}

