// Copyright (c) 2022 Ultimaker B.V.
// Cura is released under the terms of the LGPLv3 or higher.
// Modified by BigRep GmbH 2024

import QtQuick 2.10
import QtQuick.Controls 2.3
import QtQuick.Layouts 2.7

import UM 1.5 as UM
import Cura 1.0 as Cura

Button
{
    id: machineTypeListButton

    width: parent.width
    height: UM.Theme.getSize("large_button").height
    leftPadding: UM.Theme.getSize("default_margin").width
    rightPadding: UM.Theme.getSize("default_margin").width
    checkable: true
    hoverEnabled: true

    property var machineTypesModel

    contentItem: Item
    {
        id: buttonContent

        width: machineTypeListButton.width - machineTypeListButton.leftPadding - machineTypeListButton.rightPadding
        height: UM.Theme.getSize("action_button").height

        RowLayout
        {
            spacing: 0
            height: parent.height
            width: parent.width

            UM.ColorImage
            {
                id: printerIcon
                height: UM.Theme.getSize("medium_button").height
                width: UM.Theme.getSize("medium_button").width
                color: UM.Theme.getColor("machine_selector_printer_icon")
                source: model.iconName ? UM.Theme.getIcon(machineTypesModel.iconName) : UM.Theme.getIcon("Printer", "medium")
            }

            Item
            {
                // Spacer
                width: UM.Theme.getSize("default_margin").width
            }

            UM.Label
            {
                id: buttonText
                text: machineTypesModel.machineType ? machineTypesModel.machineType : ""
                
                font: model.isAbstractMachine ? UM.Theme.getFont("medium_bold") : UM.Theme.getFont("medium")
                visible: text != ""
                elide: Text.ElideRight
            }

            Item
            {
                Layout.fillWidth: true
            }

            UM.ColorImage
            {
                height: UM.Theme.getSize("default_arrow").height
                width: UM.Theme.getSize("default_arrow").width
                color: UM.Theme.getColor("setting_control_text")
                source: UM.Theme.getIcon("ChevronSingleRight")
            }

            Item
            {
                // Right side margin
                width: UM.Theme.getSize("default_margin").width
            }
        }
    }

    background: Rectangle
    {
        id: backgroundRect
        color: machineTypeListButton.hovered ? UM.Theme.getColor("action_button_hovered") : "transparent"
    }

    MouseArea {
        anchors.fill: parent
        hoverEnabled: true

        onEntered: {
            showTimer.restartTimer()
        }
        onExited: {
            hideTimer.restartTimer()
        }
    }

    Timer
    {
        id: showTimer
        interval: 250
        function restartTimer()
        {
            restart();
            running = Qt.binding(function() { return machineTypeListButton.enabled && machineTypeListButton.contentItem.containsMouse; });
            hideTimer.running = false;
        }
        onTriggered: machineInstancePopup.open()
    }
    Timer
    {
        id: hideTimer
        interval: 250
        function restartTimer() //Restart but re-evaluate the running property then.
        {
            restart();
            running = Qt.binding(function() { return machineTypeListButton.enabled && !machineTypeListButton.contentItem.containsMouse && !machineInstancePopup.itemHovered > 0; });
            showTimer.running = false;
        }
        onTriggered: machineInstancePopup.close()
    }

    MachineTypeSubMenu
    {
        id: machineInstancePopup

        // Nasty hack to ensure that we can keep track if the popup contains the mouse.
        // Since we also want a hover for the sub items (and these events are sent async)
        // We have to keep a count of itemHovered (instead of just a bool)
        property int itemHovered: 0

        Column
        {
            id: materialColorsList
            property var machines: machineTypesModel.machines
            width: machineTypeListButton.width
            height: childrenRect.height
            spacing: 0

            Repeater
            {
                model: parent.machines

                delegate: Rectangle
                {
                    height: UM.Theme.getSize("action_button").height
                    width: parent.width

                    color: machineInstanceButton.containsMouse ? UM.Theme.getColor("action_button_hovered") : "transparent"

                    MouseArea
                    {
                        id: machineInstanceButton
                        anchors.fill: parent
                        hoverEnabled: true
                        onClicked:
                        {
                            Cura.MachineManager.setActiveMachine(model.id);
                            machineInstancePopup.close();
                            machineSelectorMajor.toggleContent();
                        }
                        onEntered:
                        {
                            machineInstancePopup.itemHovered += 1;
                        }
                        onExited:
                        {
                            machineInstancePopup.itemHovered -= 1;
                        }
                    }

                    Item
                    {
                        height: parent.height
                        width: parent.width
                        anchors.fill: parent

                        UM.Label
                        {
                            text: model.name
                            anchors.left: parent.left
                            anchors.leftMargin: UM.Theme.getSize("default_margin").width + UM.Theme.getSize("default_arrow").height
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.right: parent.right
                            anchors.rightMargin: UM.Theme.getSize("default_margin").width
                            font: UM.Theme.getFont("medium")
                            elide: Label.ElideRight
                            wrapMode: Text.NoWrap
                        }
                    }
                }
            }
        }
    }
}
