import argparse
from pathlib import Path
import yaml

"""Checks that a tag release is valid to continue. This saves time"""

def verifyTag(tag:str):
    """Tag must be a sematic version with only 3 parts"""
    v = tag.split('.')
    assert len(v) == 3, f"ERROR: {tag}  must be sematic version major.minor.patch"
    
    for item in v:
        try:
            int(item)
        except:
            raise ValueError(f"ERROR: {item} in tag: {tag}, is not valid")
        
    print("Tag is suitable")

def verifyGitlab(tag:str, gitlab_version:str):
    assert tag==gitlab_version, f"Tag, {tag}, does not match the version stem, {gitlab_version}, in .gitlab-ci.yml"
    print("Gitlab is suitable")

def verifyChangelog(tag:str, changelog_file:Path):
    with open(changelog_file, 'r') as file:
        lines = file.readlines()
    
    # remove empty lines and then first line must start with '# major.minor.patch'
    for line in lines:
        l = line.strip()
        if l=="":
            continue
        elif l.startswith(f"# {tag}"):
            break
        else:
            raise ValueError(f"The first non empty line in the changelog must be: # major.minor.path and match the current tag.\n instead it was: {line}")
    print("Changelog is suitable")

def verifyYaml(tag:str, yaml_file:str):
    with open(yaml_file, 'r') as file:
        req = yaml.safe_load(file)
    
    if tag not in req:
        raise ValueError("the requirements file must contain a frozen version with the same version as the tag. refer to readme on how to do this")
    print("Conandata requirements file is frozen correctly")

if __name__ == '__main__':
    parser = argparse.ArgumentParser(
        description='Write the latest.json file')

    requiredNamed = parser.add_argument_group('Required named arguments')
    requiredNamed.add_argument("--tag", required=True)
    requiredNamed.add_argument("--changelog", required=True)
    requiredNamed.add_argument("--gitlab-version", required=True)
    requiredNamed.add_argument("--yaml", required=True)
    args = parser.parse_args()

    verifyTag(args.tag)
    verifyGitlab(args.tag,args.gitlab_version)
    verifyChangelog(args.tag,Path(args.changelog))
    verifyYaml(args.tag,Path(args.yaml))
