import yaml
import os

from conan import ConanFile
from conans.util.files import load

required_conan_version = "<=1.56"

class Freezer(ConanFile):
    name = "freezer"
    license = "LGPL-3.0"
    author = "BigRep GmbH, Matthew McMillan"
    description = "A small conan tool to build a frozen version number into the conandata.yml file"
    topics = ("conan")
    settings = "os"
    no_copy_source = True  # We won't build so no need to copy sources to the build folder
    
    options = {
        "version": "ANY",
    }
    default_options = {
        "version": "any",
    }

    def layout(self):
        self.folders.generators = 'conanfileFreezeGenerators'
        self.folders.build = '..'
        
    def requirements(self):
        self.run("pip install pyyaml")
        self.requires("conan-common/0.7.1@bigrep/main")
    
    def imports(self):
        self.copy("freeze-release.py", src = self.deps_cpp_info["conan-common"].resdirs[0], dst = "..", keep_path = False)
        
    def validate(self):
        conandata = load('conandata.yml')
        conandata = yaml.safe_load(conandata)
        v = str(self.options.version)
        if v in conandata:
            raise ValueError("You must specify the options version eg: -o version=1.2.3 and the version must not already be present in the conandata.yml file")

    def build(self):
        v = str(self.options.version)
        print(f"Freezing version: {v} based on any")
        self.run(f'python freeze-release.py -p . -v {v}')
