import argparse


def create_cmd(tag: str, job_id: int, pipeline_id: str):
    """Create the cmd bat file
    """
    lines = [  # will be joined with '^\n'
        f".\\release-cli.exe --server-url \"https://gitlab.bigrep.com\"",
        f"--project-id 267 --job-token %1",
        f"create --description \"Automated release from tag: {tag}\" --tag-name \"{tag}\"",
    ]

    asset_items = [
        ["Changelog", f"https://gitlab.bigrep.com/blade/blade-client/-/jobs/{job_id}/artifacts/raw/resources/texts/change_log_client.md"],
        ["Installer",
         f"https://gitlab.bigrep.com/blade/blade-client/-/jobs/{job_id}/artifacts/raw/dist/temp_installer_dir/blade-installer-{pipeline_id}.exe"],
        ["Material Status",
         f"https://gitlab.bigrep.com/blade/blade-client/-/jobs/{job_id}/artifacts/raw/resources/texts/material_status.csv"],
        ["latest.json",
         f"https://gitlab.bigrep.com/blade/blade-client/-/jobs/{job_id}/artifacts/raw/latest.json"],
        ["Source Code",
         f"https://gitlab.bigrep.com/blade/blade-client/-/jobs/{job_id}/artifacts/raw/BigRep_Blade_Client_Source_Code-{tag}.zip"],
    ]
    for lhs, rhs in asset_items:
        lines.append(f"--assets-link \"{{\\\"name\\\":\\\"{lhs}\\\",\\\"url\\\":\\\"{rhs}\\\"}}\"")

    msg = ' ^\n'.join(lines)
    final = f"echo \"creating a release with tag={tag}\" \n\n{msg}"
    with open('release_pipeline.bat', 'w') as file:
        file.write(final)


if __name__ == '__main__':
    parser = argparse.ArgumentParser(
        description='A tool to dynamically build release pipelines')

    requiredNamed = parser.add_argument_group('Required named arguments')
    requiredNamed.add_argument("--job_id", required=True, help="build job ID required for links")
    requiredNamed.add_argument("--pipeline_id", required=True, help="build pipeline ID required for links")
    requiredNamed.add_argument("--tag", required=True, help="build tag required for file names etc.")
    args = parser.parse_args()

    # create cmd file for pipeline
    create_cmd(args.tag, args.job_id, args.pipeline_id)
